/*
Camera Aspect Ratio.js

12-17-2013: Alpha
01-06-2014: v1.0 - First basic working version. Monitor sizes only.
01-07-2014: v1.1 - Added Imperial and Metric Sizes. Please let me know if the pixel dimensions are wrong. 

(c) 2013 Simon Strom (with Help from Edward, Trong and all the other C3d Scripters)

This script is in the public domain. Feel free to modify it or use 
it as a starting point for your own creations.

*********************************************************************

PURPOSE: 
    Creates standard pre-defined camera pixel aspect ratio proportions.
    Put into script folder "Tool"

ADD IN FUTURE VERSIONS:
    1. Increase or Decrease DPI while retaining Pixel Ratio. Not to exceed 5000px x 5000px C3d maximum
      (This is really a function of increasing pixel dimensions as C3d default is set at 72dpi.)
    2. Possibly set up a calculator for common ratios instead of fixed pixel dimensions.
    3. Set up to re-enter original camera settings if there were any.
    4. Add known brand presets (pixel dimensions & fov) for major camera makers. 

Standard Ratios from Wikipedia:
    1.33:1 (4:3)             - Traditional television & computer monitor standard
    1.41:1                   - Lichtenberg ratio / ISO 216 paper sizes / A4
    1.5:1 (3:2)              - Classic 35mm still film (not for motion pictures)
    1.6:1 (8:5 aka 16:10)    - Common computer screen ratio
    1.6180:1 (16.18:10)      - Golden ratio
    1.6667:1 (5:3)           - Common European widescreen std. / Native Super 16mm film
    1.77:1 or 1.78:1 (16:9)  - HD video std. / U.S. digital broadcast std.
    1.85:1                   - Common U.S. widescreen cinema std.
    2.39:1 or 2.40:1         - Current widescreen cinema std.
*/

var selectorArrayMonitor = ["640 x 480", "800 x 600", "1024 x 768", "1280 x 1024", "1344 x 756", "1600 x 900", "1680 x 1050", "1920 x 1080"];
var selectorArrayImperial = ["Letter Portrait", "Letter Landscape", "Legal Portrait", "Legal Landscape", "Ledger", "Tabloid"];
var selectorArrayMetric = ["A4 Portrait", "A4 Landscape", "A3 Portrait", "A3 Landscape", "B5 Portrait", "B5 Landscape", "B4 Portrait", "B4 Landscape"];
 
function buildUI(tool){
        tool.addParameterSeparator("Monitor");
        tool.addParameterSelector("Monitor Size", selectorArrayMonitor, false, false);
        tool.addParameterButton("Set Active Camera", "OK", "setCameraMonitor");
        
        tool.addParameterSeparator("Imperial");
        tool.addParameterSelector("Imperial Size", selectorArrayImperial, false, false);
        tool.addParameterButton("Set Active Camera", "OK", "setCameraImperial");

        tool.addParameterSeparator("Metric");
        tool.addParameterSelector("Metric Size", selectorArrayMetric, false, false);
        tool.addParameterButton("Set Active Camera", "OK", "setCameraMetric");
    	}

/* 
	Standard Mac Monitor: 
	640x480, 800x600, 1024x768, 1280x720, 1280x1024,1344x756, 1600x900, 1680x1050, 1920x1080
*/    	
function setCameraMonitor(tool) {
    var doc = tool.document();
    var resX = 1024;
    var resY = 768;
    var oResolution = tool.getParameter("Monitor Size");
    print(oResolution);
    switch( oResolution ) {
        case 0: // 640x480
            resX = 640;
            resY = 480;
            break;
        case 1: // 800x600
            resX = 800;
            resY = 600;
            break;
        case 2: // 1024x768
            resX = 1024;
            resY = 768;
            break;
        case 3: // 1280x1024
            resX = 1280;
            resY = 1024;
            break;
        case 4: // 1344x756
            resX = 1344;
            resY = 756;
            break;
        case 5: // 1600x900
            resX = 1600;
            resY = 900;
            break;
        case 6: // 1680x1050
            resX = 1680;
            resY = 1050;
            break;
        case 7: // 1920x1080
            resX = 1920;
            resY = 1080;
            break; 
    }
          
    var camera = doc.activeCamera();
    if(camera == null)
    	print("camera is null");
    camera.setParameter("resolutionX", resX);
    camera.setParameter("resolutionY", resY);        
	}
	
/*
	Imperial Measurement Pixel Dimensions:     
	0. Letter Portrait: 	8.5"w x 11"h 	(612p x 792p)
	1. Letter Landscape: 	11"w x 8.5"h 	(792p x 612p)
	2. Legal Portrait: 		8.5"w x 14"h 	(612p x 1008p)
	3. Legal Landscape: 	14"w x 8.5"h 	(1008p x 612p)
	4. Ledger: 				17"w x 11"h 	(1224p x 792p)
	5. Tabloid: 			11"w x 17"h 	(792p x 1224p)
*/  	
function setCameraImperial(tool) {
    var doc = tool.document();
    var resX = 1024;
    var resY = 768;
    var oResolution = tool.getParameter("Imperial Size");
    print(oResolution);
    switch( oResolution ) {
        case 0: // Letter Portrait
            resX = 612;
            resY = 792;
            break;
        case 1: // Letter Landscape
            resX = 792;
            resY = 612;
            break;
        case 2: // Legal Portrait
            resX = 612;
            resY = 1008;
            break;
        case 3: // Legal Landscape
            resX = 1008;
            resY = 612;
            break;
        case 4: // Ledger
            resX = 1224;
            resY = 792;
            break;
        case 5: // Tabloid
            resX = 792;
            resY = 1224;
            break;
    }
         
    var camera = doc.activeCamera();
    if(camera == null)
    	print("camera is null");
    camera.setParameter("resolutionX", resX);
    camera.setParameter("resolutionY", resY);        
	}
    	
/*
	Metric Measurement Pixel Dimensions: Have to round, no float #'s for pixel dimensions   
	0. A4 Portrait: 	297mm x 210mm 	(841.89p x 595.28p)
	1. A4 Landscape: 	210mm x 297mm	(595.28p x 841.89p)
	2. A3 Portrait: 	420mm x 297mm 	(1190.55p x 841.89p)
	3. A3 Landscape: 	297mm x 420mm	(841.89p x 1190.55p)
	4. B5 Portrait: 	250mm x 176mm 	(728.5p x 515.91p)
	5. B5 Landscape: 	176mm x 250mm 	(515.91p x 728.5p)
	6. B4 Portrait: 	353mm x 250mm	(1031.81p x 728.5p)
	7. B4 Landscape: 	250mm x 353mm	(728.5p x 1031.81p)
*/  	
function setCameraMetric(tool) {
    var doc = tool.document();
    var resX = 1024;
    var resY = 768;
    var oResolution = tool.getParameter("Metric Size");
    print(oResolution);
    switch( oResolution ) {
        case 0: // A4 Portrait
            resX = 842;
            resY = 595;
            break;
        case 1: // A4 Landscape
            resX = 595;
            resY = 842;
            break;
        case 2: // A3 Portrait
            resX = 1191;
            resY = 842;
            break;
        case 3: // A3 Landscape
            resX = 842;
            resY = 1191;
            break;
        case 4: // B5 Portrait
            resX = 729;
            resY = 516;
            break;
        case 5: // B5 Landscape
            resX = 516;
            resY = 729;
            break;
        case 6: // B4 Portrait
            resX = 1032;
            resY = 729;
            break;
        case 7: // B4 Landscape
            resX = 729;
            resY = 1032;
            break;
    }
                   
	var camera = doc.activeCamera();
    if(camera == null)
    	print("camera is null");
    camera.setParameter("resolutionX", resX);
    camera.setParameter("resolutionY", resY);
    }             	
 
/* 
   
// DIVIDER - DPI Float
    tool.addParameterSeparator("DPI Settings - Float");
    tool.addParameterFloat("DPI",72,72,300,false,false); //These may be better suited to making hard steps with pull down menu, ie (Low-72, Med-120, SemiMed-150, High-300. See below.)
    tool.addParameterButton("Set DPI", "OK", "setDpiInfo");
       
// DIVIDER - Alternate DPI Selector
    tool.addParameterSeparator("DPI Settings - Selector");
    tool.addParameterSelector("DPI", ["72", "120", "150", "300"],false,false); // Pull down doesn't work as expected. This won't let me choose any other than the default. ???
    tool.addParameterButton("Set DPI", "OK", "setDpiInfo");
	}
	
	Camera Parameters Output in Console by C3d Macro Script.
*************************
**** Parameter Info ****
*************************
scriptName   					[String]
locked   						[Bool]
position   						[Vec3D]
rotation   						[Vec3D]
shear   						[Vec3D]
scale   						[Vec3D]
pivot   						[Vec3D]
prefrot   						[Vec3D]
postrot   						[Vec3D]
prerot   						[Vec3D]
rotorder   						[Int]
name   							[String]
activeCamera   					[Bool]
distance   						[Float]
projection   					[Int]
fieldOfView   					[Float]
zoom   							[Float]
clipNear   						[Float]
clipFar   						[Float]
cameraPivot   					[Vec3D]
antialiasingMode   				[Int]
antialiasingMinSamples   		[Int]
antialiasingMaxSamples   		[Int]
antialiasingTolerance   		[Float]
shadowsOnOff   					[Bool]
cameraLightOnOff   				[Int]
resolutionX   					[Int]
resolutionY   					[Int]
backgroundColor   				[Vec4D]
backgroundImage   				[Texture]

*/